<?php

namespace Model;

use API\script\Gateway\GatewayForm;
use API\script\Gateway\GatewayListResponseOfCandidate;
use API\script\Gateway\GatewayQuestion;

/**
 * Permet de développer les fonctions appelées par le controllerCandidate pour gérer
 * les actions de l'utilisateur
 */
class ModelCandidate
{
    /**
     * Permet de soumettre et d'envoyer la réponse à un formulaire.
     *
     * @return void
     */
    public function submitForm(): void
    {
        $answersAndCategories = $_POST['answers'];

        $dataIds = null;
        if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'submitForm') {
            $dataIdsJson = $_POST['data_ids'];
            $dataIds = json_decode($dataIdsJson);
        }

        $answer = [];
        $category = [];
        $questionsId = [];
        var_dump($answersAndCategories);
        foreach ($answersAndCategories as $answerAndCategory) {
            $exploded = explode("||",$answerAndCategory);
            if( count($exploded) == 3 ){
                $questionsId[] = $exploded[0];
                $answer[] = $exploded[1];
                $categs = $exploded[2];
                $categs = explode("_", $categs);
                array_pop($categs);
                $category[] = $categs;
            }
            else {
                $questionsId[] = array_shift($dataIds);
                $answer[] = $answerAndCategory;
                $category[] = [];
            }
        }

        $title = (new GatewayForm())->getForm()[0]["title"];
        (new GatewayListResponseOfCandidate())->insertListResponsesOfCandidate($questionsId, $answer, $category, $title);
    }

    /**
     * Permet de récupérer le code html à afficher dans la page du formulaire,
     * on récupère donc le formulaire et toutes les questions qu'il contient.
     * On les traduits en code HTML puis on le retourne. On utilise une Factory
     * pour récupèrer les questions.
     *
     * @return string
     */
    public function getForm(): string
    {
        $form = (new GatewayForm())->getForm();
        if (empty($form)) {
            return "PAS DE FORMULAIRE\n";
        }

        $title = $form[0]['title'];
        $description = $form[0]['description'];
        $questionsTab = (new GatewayQuestion())->getAllQuestions($form[0]['id']);


        $questions = Factory::getBuiltObjects($questionsTab, "Question");
        $nbQuestions = count($questions);
        $time = round(($nbQuestions * 20)/60);

        $html = "
    <h1>$title</h1>\n
    <br>
    <h3>$description</h3>\n
    <br>
    <h4><i>Temps estimé</i> : $time minutes</h4>
    <div id='container_form'>\n
        <form method='post'>\n";

        foreach ($questions as $question) {
            $html.= $question->printStrategy()."\n";
        }

        if (count($questions) > 0) {
            $html.= "\t\t\t<input type='submit' value='Envoyer' id='button' style='margin-left: 45%'>\n
\t\t\t<input type='hidden' name='data_ids' value=''>
\t\t\t<input type='hidden' name='action' value='submitForm'>
\t\t</form>\n
\t</div><br><br><br>\n";
        } else {
            $html.= "\t\t</form>\n
\t</div>\n";
        }

        return $html;
    }
}
